// ************************************************
// *  BCR Interface DLL 32 Bits functions         *
// *  Library Version 6.0                         *
// *  Copyright 2000,19 - All rigths reserved     *
// *  RECOGNIFORM TECHNOLGIES SPA                 *
// *  www.recogniform.com - info@recogniform.com  *
// ************************************************

unit recobcrapi;

interface

Const
 BCR_2of5Interlaved  = 1;
 BCR_2of5IATA = 2;
 BCR_2of5Industrial = 4;
 BCR_2of5Matrix = 8;
 BCR_2of5DataLogic  = 16;
 BCR_Code39  = 32;
 BCR_PharmaCode  = 64;
 BCR_EAN13 = 128;
 BCR_EAN8  = 256;
 BCR_UPCA  = 512;
 BCR_UPCE  = 1024;
 BCR_EXT2  = 2048;
 BCR_EXT5  = 4096;
 BCR_CodaBar  = 8192;
 BCR_MSI  = 16384;
 BCR_Code11  = 32768;
 BCR_Code128 = 65536;
 BCR_Code93 = 131072;
 BCR_Code39Extended = 262144;

 BCR_ALL_SYMBOLS = 524287;

 BCR_LeftToRight = 1;
 BCR_RightToLeft = 2;
 BCR_TopToBottom = 4;
 BCR_BottomToTop = 8;
 BCR_ALL_ORIENTATIONS = 15;
 
 BCR_NORMAL_QUALITY = 1;
 BCR_DARK_QUALITY = 2;
 BCR_LIGHT_QUALITY = 3;

 BCR_CHECKDIGIT_DISABLED=0;

 BCR_CHECKDIGIT_ENABLED=1;

//  Goal: nitialize the engine
//  Requires: company name, license string
//  Result: session handle
function BCR_Init(Company,LicenseKey:PAnsiChar):Integer; stdcall;

//  Goal: recognize barcodes (old function)
//  Requires: session handle, dib handle, code type, expected codes, min len, max len, virtual laser size, virtual laser step
//  Result: number of codes recognized
function BCR_Recognize(SessionHandle:Integer;DIBHandle:Integer;BarCodeType,ExpectedCodes,MinCodeLen,MaxCodeLen,VirtualLaserSize,VirtualLaserStep:Integer):Integer; stdcall;

//  Goal: recognize barcodes
//  Requires: session handle, dib handle, code type, expected codes, min len, max len, virtual laser size, virtual laser step, quality, orientation, check digit verification
//  Result: number of codes recognized
function BCR_RecognizeEx(SessionHandle:Integer;DIBHandle:Integer;BarCodeType,ExpectedCodes,MinCodeLen,MaxCodeLen,VirtualLaserSize,VirtualLaserStep,Quality,Orientation,VerifyCheckDigit:Integer):Integer; stdcall;

//  Goal: deinitialize the engine
//  Requires: session handle
//  Result: n/a
procedure BCR_Done(SessionHandle:Integer); stdcall;

//  Goal: retrieve the number of codes recognized
//  Requires: session handle
//  Result: number of codes recognized in last operation
function BCR_GetCodesCount(SessionHandle:Integer):Integer; stdcall;

//  Goal: retrieve the number of recognized characters in a barcode
//  Requires: session handle, code index
//  Result: number of char(s) recognized for specified barcode
function BCR_GetCodeLen(SessionHandle:Integer;ResultIndex:Integer):Integer; stdcall;

//  Goal: retrieve the ASCII data recognized in a barcode
//  Requires: session handle, code index, output buffer
//  Result: number of characters moved in the buffer
function BCR_GetCodeText(SessionHandle:Integer;ResultIndex:Integer;Buffer:PAnsiChar):Integer; stdcall;

//  Goal: retrieve the rect coordinates of one of barcode recognized
//  Requires: session handle, code index, left, top, right and bottom output long buffer
//  Result: n/a
procedure BCR_GetCodeArea(SessionHandle:Integer;ResultIndex:Integer;Var X1,Y1,X2,Y2:Integer); stdcall;

//  Goal: retrieve the status of checkdigit for a barcode
//  Requires: session handle, code index
//  Result: status of checkdigit (0=not found or invalid, 1 found and valid)
function BCR_GetCodeCheck(SessionHandle:Integer;ResultIndex:Integer):Integer; stdcall;

//  Goal: retrieve the orientation of recognized characters in a barcode
//  Requires: session handle, code index
//  Result: the orientation of barcode (see constants values)
function BCR_GetCodeOrientation(SessionHandle:Integer;ResultIndex:Integer):Integer; stdcall;

//  Goal: retrieve the type of recognized barcode
//  Requires: session handle, code index
//  Result: code tyoe (see #define section)
function BCR_GetCodeType(SessionHandle:Integer;ResultIndex:Integer):Integer; stdcall;

//  Goal: open an image file and make available a DIB handle
//  Requires: session handle, filename
//  Result: the DIB handle
function BCR_LoadImage(SessionHandle:Integer;FileName:PAnsiChar):Integer; stdcall;

//  Goal: free from memory a DIB handle obtained from BCR_OpenImage or BCR_ImportDDB
//  Requires: session handle, DIB handle
//  Result: the DIB handle
procedure BCR_FreeImage(SessionHandle:Integer;DIBHandle:Integer); stdcall;

//  Goal: import a DDB handle making available it as DIB handle
//  Requires: session handle, DDB handle, DDB palette handle
//  Result: the DIB handle
function BCR_ImportDDB(SessionHandle:Integer;BitmapHandle:Integer;PaletteHandle:Integer):Integer; stdcall;


// Goal: recognize barcodes in area
// Requires: session handle, dib handle, Left, Top, Right, Bottom, code type, expected codes, min len, max len, virtual laser size, virtual laser step, image quality, orientation, check digit verification flag
// Result: number of codes recognized
function BCR_RecognizeArea(SessionHandle, DIBHandle, Left, Top, Right, Bottom, CodeType, MaxCodes, MinLen, MaxLen, LaserSize, LaserStep, Quality, Orientation, VerifyCheckDigit:Integer) :Integer; stdcall;


implementation

function BCR_Init(Company,LicenseKey:PAnsiChar):Integer; stdcall; external 'recobcr.dll'

function BCR_Recognize(SessionHandle:Integer;DIBHandle:Integer;BarCodeType,ExpectedCodes,MinCodeLen,MaxCodeLen,VirtualLaserSize,VirtualLaserStep:Integer):Integer; stdcall; external 'recobcr.dll'

function BCR_RecognizeEx(SessionHandle:Integer;DIBHandle:Integer;BarCodeType,ExpectedCodes,MinCodeLen,MaxCodeLen,VirtualLaserSize,VirtualLaserStep,Quality,Orientation,VerifyCheckDigit:Integer):Integer; stdcall; external 'recobcr.dll'

procedure BCR_Done(SessionHandle:Integer); stdcall; external 'recobcr.dll'

function BCR_GetCodesCount(SessionHandle:Integer):Integer; stdcall; external 'recobcr.dll'

function BCR_GetCodeLen(SessionHandle:Integer;ResultIndex:Integer):Integer; stdcall; external 'recobcr.dll'

function BCR_GetCodeText(SessionHandle:Integer;ResultIndex:Integer;Buffer:PAnsiChar):Integer; stdcall; external 'recobcr.dll'

procedure BCR_GetCodeArea(SessionHandle:Integer;ResultIndex:Integer;Var X1,Y1,X2,Y2:Integer); stdcall; external 'recobcr.dll'

function BCR_GetCodeCheck(SessionHandle:Integer;ResultIndex:Integer):Integer; stdcall; external 'recobcr.dll'

function BCR_GetCodeOrientation(SessionHandle:Integer;ResultIndex:Integer):Integer; stdcall; external 'recobcr.dll'

function BCR_GetCodeType(SessionHandle:Integer;ResultIndex:Integer):Integer; stdcall; external 'recobcr.dll'

function BCR_LoadImage(SessionHandle:Integer;FileName:PAnsiChar):Integer; stdcall; external 'recobcr.dll'

procedure BCR_FreeImage(SessionHandle:Integer;DIBHandle:Integer); stdcall; external 'recobcr.dll'

function BCR_ImportDDB(SessionHandle:Integer;BitmapHandle:Integer;PaletteHandle:Integer):Integer; stdcall; external 'recobcr.dll'

function BCR_RecognizeArea(SessionHandle, DIBHandle, Left, Top, Right, Bottom, CodeType, MaxCodes, MinLen, MaxLen, LaserSize, LaserStep, Quality, Orientation, VerifyCheckDigit:Integer) :Integer; stdcall;external 'recobcr.dll'

end.
